<?php
/**
 * Featured widgets
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Joblist_Widget_Featured extends Widget_Base {

	public function get_name() {
		return 'joblist-featured';
	}

	public function get_title() {
		return esc_html__( 'Featured Jobs', 'joblist' );
	}

	public function get_icon() {
		return 'eicon-posts-grid';
	}

	public function get_keywords() {
		return [ 'featured', 'jobs' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_featured',
			[
				'label' => esc_html__( 'Featured Jobs', 'joblist' ),
			]
		);

		$this->add_control(
			'count',
			[
				'label'         => esc_html__( 'Posts Per Page', 'joblist' ),
				'description'   => esc_html__( 'You can enter "-1" to display all items.', 'joblist' ),
				'type'          => Controls_Manager::TEXT,
				'default'       => '3',
				'label_block'   => true,
			]
		);

		$this->add_control(
			'order',
			[
				'label'         => esc_html__( 'Order', 'joblist' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''          => esc_html__( 'Default', 'joblist' ),
					'DESC'      => esc_html__( 'DESC', 'joblist' ),
					'ASC'       => esc_html__( 'ASC', 'joblist' ),
				],
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'         => esc_html__( 'Order By', 'joblist' ),
				'type'          => Controls_Manager::SELECT,
				'default'       => '',
				'options'       => [
					''              => esc_html__( 'Default', 'joblist' ),
					'date'          => esc_html__( 'Date', 'joblist' ),
					'title'         => esc_html__( 'Title', 'joblist' ),
					'name'          => esc_html__( 'Name', 'joblist' ),
					'modified'      => esc_html__( 'Modified', 'joblist' ),
					'author'        => esc_html__( 'Author', 'joblist' ),
					'rand'          => esc_html__( 'Random', 'joblist' ),
					'ID'            => esc_html__( 'ID', 'joblist' ),
					'comment_count' => esc_html__( 'Comment Count', 'joblist' ),
					'menu_order'    => esc_html__( 'Menu Order', 'joblist' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_elements',
			[
				'label' => esc_html__( 'Elements', 'joblist' ),
			]
		);

		$this->add_control(
			'heading_text',
			[
				'label'          => esc_html__( 'Heading Text', 'joblist' ),
				'type'           => Controls_Manager::TEXT,
				'default'        => esc_html__( 'Featured Jobs', 'joblist' )
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_heading_color',
			[
				'label'         => esc_html__( 'Heading', 'joblist' ),
				'tab'           => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label'         => esc_html__( 'Color', 'joblist' ),
				'type'          => Controls_Manager::COLOR,
				'selectors'     => [
					'{{WRAPPER}} .job-featured .job-featured-heading' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'          => 'heading_typography',
				'selector'      => '{{WRAPPER}} .job-featured .job-featured-heading',
				'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();
		global $post;

		// Vars
		$posts_per_page = $settings['count'];
		$order 			= $settings['order'];
		$orderby  		= $settings['orderby'];

		$args = array(
			'posts_per_page'    => $posts_per_page,
			'order'             => $order,
			'orderby'           => $orderby,
			'post_type'         => 'job_listing',
			'meta_query'        => array(
				array(
					'key'     => '_featured',
					'value'   => '1',
					'compare' => '='
				)
			)
		);

		// Build the WordPress query
		$jobs = new \WP_Query( $args );

		// Output posts
		if ( $jobs->have_posts() ) :

			// Vars
			$heading  = $settings['heading_text'];
			?>

			<div class="job-featured">

				<h3 class="job-featured-heading"><?php echo esc_html( $heading ); ?></h3>

				<div class="job-featured-columns">

					<?php
					// Start loop
					while ( $jobs->have_posts() ) : $jobs->the_post(); ?>

						<?php
							// Get the location.
							$location = get_post_meta( $post->ID, '_job_location', true );

							// Get the job type.
							$types = get_the_terms( $post->ID, 'job_listing_type' );
						?>

						<div class="job-featured-column">

							<?php joblist_post_thumbnail( 'joblist-featured-jobs' ); ?>

							<div class="job-featured-content">
								<?php the_title( sprintf( '<h2 class="job-featured-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

								<div class="job-featured-meta">
									<div class="location"><?php echo esc_html( $location ); ?></div>
									<?php if ( ! empty( $types ) ) : foreach ( $types as $type ) : ?>
									<div class="job-type <?php echo esc_attr( sanitize_title( $type->slug ) ); ?>"><?php echo esc_html( $type->name ); ?></div>
								<?php endforeach; endif; ?>
								</div>

								<?php the_excerpt(); ?>
							</div>

						</div>

					<?php endwhile; ?>

				</div>

			</div>

		<?php
			// Reset the post data to prevent conflicts with WP globals
			wp_reset_postdata();

		// If no posts are found display message
		else : ?>

			<p><?php _e( 'It seems we can&rsquo;t find what you&rsquo;re looking for.', 'joblist' ); ?></p>

		<?php
		// End post check
		endif; ?>

	<?php
	}

}

Plugin::instance()->widgets_manager->register_widget_type( new Joblist_Widget_Featured() );
