<?php
/**
 * Search widgets
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Joblist_Widget_Search extends Widget_Base {

	public function get_name() {
		return 'joblist-search';
	}

	public function get_title() {
		return esc_html__( 'Search Jobs', 'joblist' );
	}

	public function get_icon() {
		return 'eicon-search';
	}

	public function get_keywords() {
		return [ 'search', 'jobs' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'section_heading',
			[
				'label' => esc_html__( 'Heading', 'joblist' ),
			]
		);

		$this->add_control(
			'heading_text',
			[
				'label'          => esc_html__( 'Heading Text', 'joblist' ),
				'type'           => Controls_Manager::TEXT,
				'default'        => esc_html__( 'Find a new carrer designed for you.', 'joblist' )
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_heading_color',
			[
				'label'         => esc_html__( 'Heading', 'joblist' ),
				'tab'           => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'heading_color',
			[
				'label'         => esc_html__( 'Color', 'joblist' ),
				'type'          => Controls_Manager::COLOR,
				'selectors'     => [
					'{{WRAPPER}} .job-search .job-search-heading' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'          => 'heading_typography',
				'selector'      => '{{WRAPPER}} .job-search .job-search-heading',
				'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_job_count',
			[
				'label'         => esc_html__( 'Job Count', 'joblist' ),
				'tab'           => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'job_count',
			[
				'label'         => esc_html__( 'Color', 'joblist' ),
				'type'          => Controls_Manager::COLOR,
				'selectors'     => [
					'{{WRAPPER}} .job-search .job-search-job-count' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'          => 'job_count_typography',
				'selector'      => '{{WRAPPER}} .job-search .job-search-job-count',
				'scheme'        => Scheme_Typography::TYPOGRAPHY_1,
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings();

		// Vars
		$heading = $settings['heading_text'];
		$count   = wp_count_posts( 'job_listing' );
		?>

		<div class="job-search">

			<h2 class="job-search-heading"><?php echo esc_html( $heading ); ?></h2>

			<form class="job-search-form" method="GET" action="<?php echo esc_url( home_url( '/jobs' ) ); ?>">
				<p>
					<input type="text" id="search_keywords" name="search_keywords" placeholder="<?php esc_attr_e( 'job title or keywords', 'joblist' ); ?>" />
				</p>
				<p>
					<input type="text" id="search_location" name="search_location" placeholder="<?php esc_attr_e( 'location', 'joblist' ); ?>" />
				</p>
				<p>
					<button type="submit"><span class="icon-search"></span></button>
				</p>
			</form>

			<p class="job-search-job-count">
				<?php printf( esc_html__( 'Search over %s current open positions.', 'joblist' ), $count->publish ); ?>
			</p>

		</div>

	<?php
	}

}

Plugin::instance()->widgets_manager->register_widget_type( new Joblist_Widget_Search() );
